@@ -9,7 +9,7 @@ import pytest
 from sshtunnel import SSHTunnelForwarder
 
 from hdx.database import Database
-from hdx.database.postgres import wait_for_postgres
+from hdx.database.postgresql import wait_for_postgresql
 
 
 class TestDatabase:
@@ -23,9 +23,9 @@ class TestDatabase:
         "port": 1234,
         "username": "myuser",
         "password": "mypass",
-        "driver": "postgres",
+        "driver": "postgresql",
     }
-    sqlalchemy_url = "postgres://myuser:mypass@myserver:1234/mydatabase"
+    sqlalchemy_url = "postgresql://myuser:mypass@myserver:1234/mydatabase"
 
     @pytest.fixture(scope="function")
     def nodatabase(self):
@@ -83,16 +83,18 @@ class TestDatabase:
         monkeypatch.setattr(Database, "get_session", get_session)
 
     def test_get_params_from_sqlalchemy_url(self):
-        result = Database.get_params_from_sqlalchemy_url(TestDatabase.sqlalchemy_url)
+        result = Database.get_params_from_sqlalchemy_url(
+            TestDatabase.sqlalchemy_url
+        )
         assert result == TestDatabase.params
 
     def test_get_sqlalchemy_url(self):
         result = Database.get_sqlalchemy_url(**TestDatabase.params)
         assert result == TestDatabase.sqlalchemy_url
 
-    def test_wait_for_postgres(self, mock_psycopg2):
+    def test_wait_for_postgresql(self, mock_psycopg2):
         TestDatabase.connected = False
-        wait_for_postgres("mydatabase", "myserver", 5432, "myuser", "mypass")
+        wait_for_postgresql("mydatabase", "myserver", 5432, "myuser", "mypass")
         assert TestDatabase.connected is True
 
     def test_get_session(self, nodatabase):
@@ -102,15 +104,19 @@ class TestDatabase:
             assert str(dbsession.bind.engine.url) == nodatabase
 
     def test_get_session_ssh(self, mock_psycopg2, mock_SSHTunnelForwarder):
-        with Database(ssh_host="mysshhost", **TestDatabase.params) as dbsession:
+        with Database(
+            ssh_host="mysshhost", **TestDatabase.params
+        ) as dbsession:
             assert (
                 str(dbsession.bind.engine.url)
-                == "postgres://myuser:mypass@0.0.0.0:12345/mydatabase"
+                == "postgresql://myuser:mypass@0.0.0.0:12345/mydatabase"
             )
         params = copy.deepcopy(TestDatabase.params)
         del params["password"]
-        with Database(ssh_host="mysshhost", ssh_port=25, **params) as dbsession:
+        with Database(
+            ssh_host="mysshhost", ssh_port=25, **params
+        ) as dbsession:
             assert (
                 str(dbsession.bind.engine.url)
-                == "postgres://myuser@0.0.0.0:12345/mydatabase"
+                == "postgresql://myuser@0.0.0.0:12345/mydatabase"
             )
